@@ -2,31 +2,30 @@
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct Intent {
     /// Required. The name of the last matched intent.
-    #[prost(string, tag = "1")]
+    #[prost(string, tag="1")]
     pub name: ::prost::alloc::string::String,
     /// Required. Represents parameters identified as part of intent matching.
     /// This is a map of the name of the identified parameter to the value of the
     /// parameter identified from user input. All parameters defined in
     /// the matched intent that are identified will be surfaced here.
-    #[prost(btree_map = "string, message", tag = "2")]
-    pub params:
-        ::prost::alloc::collections::BTreeMap<::prost::alloc::string::String, IntentParameterValue>,
+    #[prost(btree_map="string, message", tag="2")]
+    pub params: ::prost::alloc::collections::BTreeMap<::prost::alloc::string::String, IntentParameterValue>,
     /// Optional. Typed or spoken input from the end user that matched this intent.
     /// This will be populated when an intent is matched, based on the user input.
-    #[prost(string, tag = "3")]
+    #[prost(string, tag="3")]
     pub query: ::prost::alloc::string::String,
 }
 /// Represents a value for intent parameter.
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct IntentParameterValue {
     /// Required. Original text value extracted from user utterance.
-    #[prost(string, tag = "1")]
+    #[prost(string, tag="1")]
     pub original: ::prost::alloc::string::String,
     /// Required. Structured value for parameter extracted from user input.
     /// This will only be populated if the parameter is defined in the matched
     /// intent and the value of the parameter could be identified during intent
     /// matching.
-    #[prost(message, optional, tag = "2")]
+    #[prost(message, optional, tag="2")]
     pub resolved: ::core::option::Option<::prost_types::Value>,
 }
 /// Represents an Interactive Canvas response to be sent to the user.
@@ -37,23 +36,23 @@ pub struct IntentParameterValue {
 pub struct Canvas {
     /// URL of the interactive canvas web app to load. If not set, the url from
     /// current active canvas will be reused.
-    #[prost(string, tag = "1")]
+    #[prost(string, tag="1")]
     pub url: ::prost::alloc::string::String,
     /// Optional. JSON data to be passed through to the immersive experience
     /// web page as an event.
     /// If the "override" field in the containing prompt is "false" data values
     /// defined in this Canvas prompt will be added after data values defined in
     /// previous Canvas prompts.
-    #[prost(message, repeated, tag = "4")]
+    #[prost(message, repeated, tag="4")]
     pub data: ::prost::alloc::vec::Vec<::prost_types::Value>,
     /// Optional. Default value: false.
-    #[prost(bool, tag = "3")]
+    #[prost(bool, tag="3")]
     pub suppress_mic: bool,
     /// If `true` the canvas application occupies the full screen and won't
     /// have a header at the top. A toast message will also be displayed on the
     /// loading screen that includes the Action's display name, the developer's
     /// name, and instructions for exiting the Action. Default value: `false`.
-    #[prost(bool, tag = "8")]
+    #[prost(bool, tag="8")]
     pub enable_full_screen: bool,
 }
 /// An image displayed in the card.
@@ -61,20 +60,20 @@ pub struct Canvas {
 pub struct Image {
     /// The source url of the image. Images can be JPG, PNG and GIF (animated and
     /// non-animated). For example,`<https://www.agentx.com/logo.png`.> Required.
-    #[prost(string, tag = "1")]
+    #[prost(string, tag="1")]
     pub url: ::prost::alloc::string::String,
     /// A text description of the image to be used for accessibility, e.g. screen
     /// readers.
     /// Required.
-    #[prost(string, tag = "2")]
+    #[prost(string, tag="2")]
     pub alt: ::prost::alloc::string::String,
     /// The height of the image in pixels.
     /// Optional.
-    #[prost(int32, tag = "3")]
+    #[prost(int32, tag="3")]
     pub height: i32,
     /// The width of the image in pixels.
     /// Optional.
-    #[prost(int32, tag = "4")]
+    #[prost(int32, tag="4")]
     pub width: i32,
 }
 /// Nested message and enum types in `Image`.
@@ -104,10 +103,10 @@ pub mod image {
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct Link {
     /// Name of the link
-    #[prost(string, tag = "1")]
+    #[prost(string, tag="1")]
     pub name: ::prost::alloc::string::String,
     /// What happens when a user opens the link
-    #[prost(message, optional, tag = "2")]
+    #[prost(message, optional, tag="2")]
     pub open: ::core::option::Option<OpenUrl>,
 }
 /// Action taken when a user opens a link.
@@ -115,10 +114,10 @@ pub struct Link {
 pub struct OpenUrl {
     /// The url field which could be any of:
     /// - http/https urls for opening an App-linked App or a webpage
-    #[prost(string, tag = "1")]
+    #[prost(string, tag="1")]
     pub url: ::prost::alloc::string::String,
     /// Indicates a hint for the url type.
-    #[prost(enumeration = "UrlHint", tag = "2")]
+    #[prost(enumeration="UrlHint", tag="2")]
     pub hint: i32,
 }
 /// Different types of url hints.
@@ -136,42 +135,42 @@ pub enum UrlHint {
 pub struct Card {
     /// Overall title of the card.
     /// Optional.
-    #[prost(string, tag = "1")]
+    #[prost(string, tag="1")]
     pub title: ::prost::alloc::string::String,
     /// Optional.
-    #[prost(string, tag = "2")]
+    #[prost(string, tag="2")]
     pub subtitle: ::prost::alloc::string::String,
     /// Body text of the card.
     /// Supports a limited set of markdown syntax for formatting.
     /// Required, unless image is present.
-    #[prost(string, tag = "3")]
+    #[prost(string, tag="3")]
     pub text: ::prost::alloc::string::String,
     /// A hero image for the card. The height is fixed to 192dp.
     /// Optional.
-    #[prost(message, optional, tag = "4")]
+    #[prost(message, optional, tag="4")]
     pub image: ::core::option::Option<Image>,
     /// How the image background will be filled. Optional.
-    #[prost(enumeration = "image::ImageFill", tag = "5")]
+    #[prost(enumeration="image::ImageFill", tag="5")]
     pub image_fill: i32,
     /// Button.
     /// Optional.
-    #[prost(message, optional, tag = "6")]
+    #[prost(message, optional, tag="6")]
     pub button: ::core::option::Option<Link>,
 }
 /// A card for presenting a collection of options to select from.
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct Collection {
     /// Title of the collection. Optional.
-    #[prost(string, tag = "1")]
+    #[prost(string, tag="1")]
     pub title: ::prost::alloc::string::String,
     /// Subtitle of the collection. Optional.
-    #[prost(string, tag = "2")]
+    #[prost(string, tag="2")]
     pub subtitle: ::prost::alloc::string::String,
     /// min: 2 max: 10
-    #[prost(message, repeated, tag = "3")]
+    #[prost(message, repeated, tag="3")]
     pub items: ::prost::alloc::vec::Vec<collection::CollectionItem>,
     /// How the image backgrounds of collection items will be filled. Optional.
-    #[prost(enumeration = "image::ImageFill", tag = "4")]
+    #[prost(enumeration="image::ImageFill", tag="4")]
     pub image_fill: i32,
 }
 /// Nested message and enum types in `Collection`.
@@ -181,7 +180,7 @@ pub mod collection {
     pub struct CollectionItem {
         /// Required. The NLU key that matches the entry key name in the associated
         /// Type.
-        #[prost(string, tag = "1")]
+        #[prost(string, tag="1")]
         pub key: ::prost::alloc::string::String,
     }
 }
@@ -189,13 +188,13 @@ pub mod collection {
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct List {
     /// Title of the list. Optional.
-    #[prost(string, tag = "1")]
+    #[prost(string, tag="1")]
     pub title: ::prost::alloc::string::String,
     /// Subtitle of the list. Optional.
-    #[prost(string, tag = "2")]
+    #[prost(string, tag="2")]
     pub subtitle: ::prost::alloc::string::String,
     /// min: 2 max: 30
-    #[prost(message, repeated, tag = "3")]
+    #[prost(message, repeated, tag="3")]
     pub items: ::prost::alloc::vec::Vec<list::ListItem>,
 }
 /// Nested message and enum types in `List`.
@@ -205,7 +204,7 @@ pub mod list {
     pub struct ListItem {
         /// Required. The NLU key that matches the entry key name in the associated
         /// Type.
-        #[prost(string, tag = "1")]
+        #[prost(string, tag="1")]
         pub key: ::prost::alloc::string::String,
     }
 }
@@ -214,19 +213,19 @@ pub mod list {
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct Media {
     /// Media type.
-    #[prost(enumeration = "media::MediaType", tag = "8")]
+    #[prost(enumeration="media::MediaType", tag="8")]
     pub media_type: i32,
     /// Start offset of the first media object.
-    #[prost(message, optional, tag = "5")]
+    #[prost(message, optional, tag="5")]
     pub start_offset: ::core::option::Option<::prost_types::Duration>,
     /// Optional media control types this media response session can support.
     /// If set, request will be made to 3p when a certain media event happens.
     /// If not set, 3p must still handle two default control type, FINISHED and
     /// FAILED.
-    #[prost(enumeration = "media::OptionalMediaControls", repeated, tag = "6")]
+    #[prost(enumeration="media::OptionalMediaControls", repeated, tag="6")]
     pub optional_media_controls: ::prost::alloc::vec::Vec<i32>,
     /// List of Media Objects
-    #[prost(message, repeated, tag = "7")]
+    #[prost(message, repeated, tag="7")]
     pub media_objects: ::prost::alloc::vec::Vec<MediaObject>,
 }
 /// Nested message and enum types in `Media`.
@@ -259,23 +258,23 @@ pub mod media {
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct MediaObject {
     /// Name of this media object.
-    #[prost(string, tag = "1")]
+    #[prost(string, tag="1")]
     pub name: ::prost::alloc::string::String,
     /// Description of this media object.
-    #[prost(string, tag = "2")]
+    #[prost(string, tag="2")]
     pub description: ::prost::alloc::string::String,
     /// The url pointing to the media content.
-    #[prost(string, tag = "3")]
+    #[prost(string, tag="3")]
     pub url: ::prost::alloc::string::String,
     /// Image to show with the media card.
-    #[prost(message, optional, tag = "4")]
+    #[prost(message, optional, tag="4")]
     pub image: ::core::option::Option<MediaImage>,
 }
 /// Image to show with the media card.
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct MediaImage {
     /// Image.
-    #[prost(oneof = "media_image::Image", tags = "1, 2")]
+    #[prost(oneof="media_image::Image", tags="1, 2")]
     pub image: ::core::option::Option<media_image::Image>,
 }
 /// Nested message and enum types in `MediaImage`.
@@ -284,11 +283,11 @@ pub mod media_image {
     #[derive(Clone, PartialEq, ::prost::Oneof)]
     pub enum Image {
         /// A large image, such as the cover of the album, etc.
-        #[prost(message, tag = "1")]
+        #[prost(message, tag="1")]
         Large(super::Image),
         /// A small image icon displayed on the right from the title.
         /// It's resized to 36x36 dp.
-        #[prost(message, tag = "2")]
+        #[prost(message, tag="2")]
         Icon(super::Image),
     }
 }
@@ -296,37 +295,37 @@ pub mod media_image {
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct Table {
     /// Overall title of the table. Optional but must be set if subtitle is set.
-    #[prost(string, tag = "1")]
+    #[prost(string, tag="1")]
     pub title: ::prost::alloc::string::String,
     /// Subtitle for the table. Optional.
-    #[prost(string, tag = "2")]
+    #[prost(string, tag="2")]
     pub subtitle: ::prost::alloc::string::String,
     /// Image associated with the table. Optional.
-    #[prost(message, optional, tag = "4")]
+    #[prost(message, optional, tag="4")]
     pub image: ::core::option::Option<Image>,
     /// Headers and alignment of columns.
-    #[prost(message, repeated, tag = "5")]
+    #[prost(message, repeated, tag="5")]
     pub columns: ::prost::alloc::vec::Vec<TableColumn>,
     /// Row data of the table. The first 3 rows are guaranteed to be shown but
     /// others might be cut on certain surfaces. Please test with the simulator to
     /// see which rows will be shown for a given surface. On surfaces that support
     /// the WEB_BROWSER capability, you can point the user to
     /// a web page with more data.
-    #[prost(message, repeated, tag = "6")]
+    #[prost(message, repeated, tag="6")]
     pub rows: ::prost::alloc::vec::Vec<TableRow>,
     /// Button.
-    #[prost(message, optional, tag = "7")]
+    #[prost(message, optional, tag="7")]
     pub button: ::core::option::Option<Link>,
 }
 /// Describes a column in a table.
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct TableColumn {
     /// Header text for the column.
-    #[prost(string, tag = "1")]
+    #[prost(string, tag="1")]
     pub header: ::prost::alloc::string::String,
     /// Horizontal alignment of content w.r.t column. If unspecified, content
     /// will be aligned to the leading edge.
-    #[prost(enumeration = "table_column::HorizontalAlignment", tag = "2")]
+    #[prost(enumeration="table_column::HorizontalAlignment", tag="2")]
     pub align: i32,
 }
 /// Nested message and enum types in `TableColumn`.
@@ -349,7 +348,7 @@ pub mod table_column {
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct TableCell {
     /// Text content of the cell.
-    #[prost(string, tag = "1")]
+    #[prost(string, tag="1")]
     pub text: ::prost::alloc::string::String,
 }
 /// Describes a row in the table.
@@ -358,17 +357,17 @@ pub struct TableRow {
     /// Cells in this row. The first 3 cells are guaranteed to be shown but
     /// others might be cut on certain surfaces. Please test with the simulator
     /// to see which cells will be shown for a given surface.
-    #[prost(message, repeated, tag = "1")]
+    #[prost(message, repeated, tag="1")]
     pub cells: ::prost::alloc::vec::Vec<TableCell>,
     /// Indicates whether there should be a divider after each row.
-    #[prost(bool, tag = "2")]
+    #[prost(bool, tag="2")]
     pub divider: bool,
 }
 /// Content to be shown.
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct Content {
     /// Content.
-    #[prost(oneof = "content::Content", tags = "1, 2, 3, 4, 5, 6, 7")]
+    #[prost(oneof="content::Content", tags="1, 2, 3, 4, 5, 6, 7")]
     pub content: ::core::option::Option<content::Content>,
 }
 /// Nested message and enum types in `Content`.
@@ -377,25 +376,25 @@ pub mod content {
     #[derive(Clone, PartialEq, ::prost::Oneof)]
     pub enum Content {
         /// A basic card.
-        #[prost(message, tag = "1")]
+        #[prost(message, tag="1")]
         Card(super::Card),
         /// An image.
-        #[prost(message, tag = "2")]
+        #[prost(message, tag="2")]
         Image(super::Image),
         /// Table card.
-        #[prost(message, tag = "3")]
+        #[prost(message, tag="3")]
         Table(super::Table),
         /// Response indicating a set of media to be played.
-        #[prost(message, tag = "4")]
+        #[prost(message, tag="4")]
         Media(super::Media),
         /// A response to be used for interactive canvas experience.
-        #[prost(message, tag = "5")]
+        #[prost(message, tag="5")]
         Canvas(super::Canvas),
         /// A card presenting a collection of options to select from.
-        #[prost(message, tag = "6")]
+        #[prost(message, tag="6")]
         Collection(super::Collection),
         /// A card presenting a list of options to select from.
-        #[prost(message, tag = "7")]
+        #[prost(message, tag="7")]
         List(super::List),
     }
 }
@@ -406,14 +405,14 @@ pub struct Simple {
     /// text to speech.
     /// If the "override" field in the containing prompt is "true", the speech
     /// defined in this field replaces the previous Simple prompt's speech.
-    #[prost(string, tag = "1")]
+    #[prost(string, tag="1")]
     pub speech: ::prost::alloc::string::String,
     /// Optional text to display in the chat bubble. If not given, a display
     /// rendering of the speech field above will be used. Limited to 640
     /// chars.
     /// If the "override" field in the containing prompt is "true", the text
     /// defined in this field replaces to the previous Simple prompt's text.
-    #[prost(string, tag = "2")]
+    #[prost(string, tag="2")]
     pub text: ::prost::alloc::string::String,
 }
 /// Input suggestion to be presented to the user.
@@ -423,7 +422,7 @@ pub struct Suggestion {
     /// posted back to the conversation verbatim as if the user had typed it.
     /// Each title must be unique among the set of suggestion chips.
     /// Max 25 chars
-    #[prost(string, tag = "1")]
+    #[prost(string, tag="1")]
     pub title: ::prost::alloc::string::String,
 }
 /// Represent a response to a user.
@@ -441,7 +440,7 @@ pub struct Prompt {
     /// always be overwritten if defined in the prompt.
     /// Default value is "false".
     #[deprecated]
-    #[prost(bool, tag = "1")]
+    #[prost(bool, tag="1")]
     pub append: bool,
     /// Optional. Mode for how this messages should be merged with previously
     /// defined messages.
@@ -454,54 +453,54 @@ pub struct Prompt {
     /// and the Canvas prompt (part of the Content prompt). The Content and Link
     /// messages are always overwritten if defined in the prompt. Default
     /// value is "false".
-    #[prost(bool, tag = "8")]
+    #[prost(bool, tag="8")]
     pub r#override: bool,
     /// Optional. The first voice and text-only response.
-    #[prost(message, optional, tag = "2")]
+    #[prost(message, optional, tag="2")]
     pub first_simple: ::core::option::Option<Simple>,
     /// Optional. A content like a card, list or media to display to the user.
-    #[prost(message, optional, tag = "3")]
+    #[prost(message, optional, tag="3")]
     pub content: ::core::option::Option<Content>,
     /// Optional. The last voice and text-only response.
-    #[prost(message, optional, tag = "4")]
+    #[prost(message, optional, tag="4")]
     pub last_simple: ::core::option::Option<Simple>,
     /// Optional. Suggestions to be displayed to the user which will always appear
     /// at the end of the response.
     /// If the "override" field in the containing prompt is "false", the titles
     /// defined in this field will be added to titles defined in any previously
     /// defined suggestions prompts and duplicate values will be removed.
-    #[prost(message, repeated, tag = "5")]
+    #[prost(message, repeated, tag="5")]
     pub suggestions: ::prost::alloc::vec::Vec<Suggestion>,
     /// Optional. An additional suggestion chip that can link out to the associated app
     /// or site.
     /// The chip will be rendered with the title "Open <name>". Max 20 chars.
-    #[prost(message, optional, tag = "6")]
+    #[prost(message, optional, tag="6")]
     pub link: ::core::option::Option<Link>,
     /// Optional. Represents a Interactive Canvas response to be sent to the user.
-    #[prost(message, optional, tag = "9")]
+    #[prost(message, optional, tag="9")]
     pub canvas: ::core::option::Option<Canvas>,
 }
 /// Represents a slot.
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct Slot {
     /// The mode of the slot (required or optional). Can be set by developer.
-    #[prost(enumeration = "slot::SlotMode", tag = "1")]
+    #[prost(enumeration="slot::SlotMode", tag="1")]
     pub mode: i32,
     /// The status of the slot.
-    #[prost(enumeration = "slot::SlotStatus", tag = "2")]
+    #[prost(enumeration="slot::SlotStatus", tag="2")]
     pub status: i32,
     /// The value of the slot. Changing this value in the response, will
     /// modify the value in slot filling.
-    #[prost(message, optional, tag = "3")]
+    #[prost(message, optional, tag="3")]
     pub value: ::core::option::Option<::prost_types::Value>,
     /// Indicates if the slot value was collected on the last turn.
     /// This field is read-only.
-    #[prost(bool, tag = "4")]
+    #[prost(bool, tag="4")]
     pub updated: bool,
     /// Optional. This prompt is sent to the user when needed to fill a required
     /// slot. This prompt overrides the existing prompt defined in the console.
     /// This field is not included in the webhook request.
-    #[prost(message, optional, tag = "5")]
+    #[prost(message, optional, tag="5")]
     pub prompt: ::core::option::Option<Prompt>,
 }
 /// Nested message and enum types in `Slot`.
