@@ -3,16 +3,16 @@
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct ComputeEngine {
     /// The instance on which the operation is running.
-    #[prost(string, tag = "1")]
+    #[prost(string, tag="1")]
     pub instance_name: ::prost::alloc::string::String,
     /// The availability zone in which the instance resides.
-    #[prost(string, tag = "2")]
+    #[prost(string, tag="2")]
     pub zone: ::prost::alloc::string::String,
     /// The machine type of the instance.
-    #[prost(string, tag = "3")]
+    #[prost(string, tag="3")]
     pub machine_type: ::prost::alloc::string::String,
     /// The names of the disks that were created for this pipeline.
-    #[prost(string, repeated, tag = "4")]
+    #[prost(string, repeated, tag="4")]
     pub disk_names: ::prost::alloc::vec::Vec<::prost::alloc::string::String>,
 }
 /// Runtime metadata that will be populated in the
@@ -21,7 +21,7 @@ pub struct ComputeEngine {
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct RuntimeMetadata {
     /// Execution information specific to Google Compute Engine.
-    #[prost(message, optional, tag = "1")]
+    #[prost(message, optional, tag="1")]
     pub compute_engine: ::core::option::Option<ComputeEngine>,
 }
 /// The pipeline object. Represents a transformation from a set of input
@@ -34,20 +34,20 @@ pub struct RuntimeMetadata {
 pub struct Pipeline {
     /// Required. The project in which to create the pipeline. The caller must have
     /// WRITE access.
-    #[prost(string, tag = "1")]
+    #[prost(string, tag="1")]
     pub project_id: ::prost::alloc::string::String,
     /// Required. A user specified pipeline name that does not have to be unique.
     /// This name can be used for filtering Pipelines in ListPipelines.
-    #[prost(string, tag = "2")]
+    #[prost(string, tag="2")]
     pub name: ::prost::alloc::string::String,
     /// User-specified description.
-    #[prost(string, tag = "3")]
+    #[prost(string, tag="3")]
     pub description: ::prost::alloc::string::String,
     /// Input parameters of the pipeline.
-    #[prost(message, repeated, tag = "8")]
+    #[prost(message, repeated, tag="8")]
     pub input_parameters: ::prost::alloc::vec::Vec<PipelineParameter>,
     /// Output parameters of the pipeline.
-    #[prost(message, repeated, tag = "9")]
+    #[prost(message, repeated, tag="9")]
     pub output_parameters: ::prost::alloc::vec::Vec<PipelineParameter>,
     /// Required. Specifies resource requirements for the pipeline run.
     /// Required fields:
@@ -57,17 +57,17 @@ pub struct Pipeline {
     ///
     /// *
     /// \[minimumRamGb][google.genomics.v1alpha2.PipelineResources.minimum_ram_gb\]
-    #[prost(message, optional, tag = "6")]
+    #[prost(message, optional, tag="6")]
     pub resources: ::core::option::Option<PipelineResources>,
     /// Unique pipeline id that is generated by the service when CreatePipeline
     /// is called. Cannot be specified in the Pipeline used in the
     /// CreatePipelineRequest, and will be populated in the response to
     /// CreatePipeline and all subsequent Get and List calls. Indicates that the
     /// service has registered this pipeline.
-    #[prost(string, tag = "7")]
+    #[prost(string, tag="7")]
     pub pipeline_id: ::prost::alloc::string::String,
     /// Required. The executor indicates in which environment the pipeline runs.
-    #[prost(oneof = "pipeline::Executor", tags = "5")]
+    #[prost(oneof="pipeline::Executor", tags="5")]
     pub executor: ::core::option::Option<pipeline::Executor>,
 }
 /// Nested message and enum types in `Pipeline`.
@@ -76,7 +76,7 @@ pub mod pipeline {
     #[derive(Clone, PartialEq, ::prost::Oneof)]
     pub enum Executor {
         /// Specifies the docker run information.
-        #[prost(message, tag = "5")]
+        #[prost(message, tag="5")]
         Docker(super::DockerExecutor),
     }
 }
@@ -85,7 +85,7 @@ pub mod pipeline {
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct CreatePipelineRequest {
     /// The pipeline to create. Should not have `pipelineId` populated.
-    #[prost(message, optional, tag = "1")]
+    #[prost(message, optional, tag="1")]
     pub pipeline: ::core::option::Option<Pipeline>,
 }
 /// The pipeline run arguments.
@@ -94,46 +94,40 @@ pub struct RunPipelineArgs {
     /// Required. The project in which to run the pipeline. The caller must have
     /// WRITER access to all Google Cloud services and resources (e.g. Google
     /// Compute Engine) will be used.
-    #[prost(string, tag = "1")]
+    #[prost(string, tag="1")]
     pub project_id: ::prost::alloc::string::String,
     /// Pipeline input arguments; keys are defined in the pipeline documentation.
     /// All input parameters that do not have default values  must be specified.
     /// If parameters with defaults are specified here, the defaults will be
     /// overridden.
-    #[prost(btree_map = "string, string", tag = "2")]
-    pub inputs: ::prost::alloc::collections::BTreeMap<
-        ::prost::alloc::string::String,
-        ::prost::alloc::string::String,
-    >,
+    #[prost(btree_map="string, string", tag="2")]
+    pub inputs: ::prost::alloc::collections::BTreeMap<::prost::alloc::string::String, ::prost::alloc::string::String>,
     /// Pipeline output arguments; keys are defined in the pipeline
     /// documentation.  All output parameters of without default values
     /// must be specified.  If parameters with defaults are specified
     /// here, the defaults will be overridden.
-    #[prost(btree_map = "string, string", tag = "3")]
-    pub outputs: ::prost::alloc::collections::BTreeMap<
-        ::prost::alloc::string::String,
-        ::prost::alloc::string::String,
-    >,
+    #[prost(btree_map="string, string", tag="3")]
+    pub outputs: ::prost::alloc::collections::BTreeMap<::prost::alloc::string::String, ::prost::alloc::string::String>,
     /// The Google Cloud Service Account that will be used to access data and
     /// services. By default, the compute service account associated with
     /// `projectId` is used.
-    #[prost(message, optional, tag = "4")]
+    #[prost(message, optional, tag="4")]
     pub service_account: ::core::option::Option<ServiceAccount>,
     /// This field is deprecated. Use `labels` instead. Client-specified pipeline
     /// operation identifier.
-    #[prost(string, tag = "5")]
+    #[prost(string, tag="5")]
     pub client_id: ::prost::alloc::string::String,
     /// Specifies resource requirements/overrides for the pipeline run.
-    #[prost(message, optional, tag = "6")]
+    #[prost(message, optional, tag="6")]
     pub resources: ::core::option::Option<PipelineResources>,
     /// Required. Logging options. Used by the service to communicate results
     /// to the user.
-    #[prost(message, optional, tag = "7")]
+    #[prost(message, optional, tag="7")]
     pub logging: ::core::option::Option<LoggingOptions>,
     /// How long to keep the VM up after a failure (for example docker command
     /// failed, copying input or output files failed, etc). While the VM is up, one
     /// can ssh into the VM to debug. Default is 0; maximum allowed value is 1 day.
-    #[prost(message, optional, tag = "8")]
+    #[prost(message, optional, tag="8")]
     pub keep_vm_alive_on_failure_duration: ::core::option::Option<::prost_types::Duration>,
     /// Labels to apply to this pipeline run. Labels will also be applied to
     /// compute resources (VM, disks) created by this pipeline run. When listing
@@ -147,11 +141,8 @@ pub struct RunPipelineArgs {
     /// character must be a lowercase letter, and all following characters must be
     /// a dash, lowercase letter, or digit, except the last character, which cannot
     /// be a dash.
-    #[prost(btree_map = "string, string", tag = "9")]
-    pub labels: ::prost::alloc::collections::BTreeMap<
-        ::prost::alloc::string::String,
-        ::prost::alloc::string::String,
-    >,
+    #[prost(btree_map="string, string", tag="9")]
+    pub labels: ::prost::alloc::collections::BTreeMap<::prost::alloc::string::String, ::prost::alloc::string::String>,
 }
 /// The request to run a pipeline. If `pipelineId` is specified, it
 /// refers to a saved pipeline created with CreatePipeline and set as
@@ -163,9 +154,9 @@ pub struct RunPipelineArgs {
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct RunPipelineRequest {
     /// The arguments to use when running this pipeline.
-    #[prost(message, optional, tag = "3")]
+    #[prost(message, optional, tag="3")]
     pub pipeline_args: ::core::option::Option<RunPipelineArgs>,
-    #[prost(oneof = "run_pipeline_request::Pipeline", tags = "1, 2")]
+    #[prost(oneof="run_pipeline_request::Pipeline", tags="1, 2")]
     pub pipeline: ::core::option::Option<run_pipeline_request::Pipeline>,
 }
 /// Nested message and enum types in `RunPipelineRequest`.
@@ -173,10 +164,10 @@ pub mod run_pipeline_request {
     #[derive(Clone, PartialEq, ::prost::Oneof)]
     pub enum Pipeline {
         /// The already created pipeline to run.
-        #[prost(string, tag = "1")]
+        #[prost(string, tag="1")]
         PipelineId(::prost::alloc::string::String),
         /// A new pipeline object to run once and then delete.
-        #[prost(message, tag = "2")]
+        #[prost(message, tag="2")]
         EphemeralPipeline(super::Pipeline),
     }
 }
@@ -185,7 +176,7 @@ pub mod run_pipeline_request {
 pub struct GetPipelineRequest {
     /// Caller must have READ access to the project in which this pipeline
     /// is defined.
-    #[prost(string, tag = "1")]
+    #[prost(string, tag="1")]
     pub pipeline_id: ::prost::alloc::string::String,
 }
 /// A request to list pipelines in a given project. Pipelines can be
@@ -198,20 +189,20 @@ pub struct GetPipelineRequest {
 pub struct ListPipelinesRequest {
     /// Required. The name of the project to search for pipelines. Caller
     /// must have READ access to this project.
-    #[prost(string, tag = "1")]
+    #[prost(string, tag="1")]
     pub project_id: ::prost::alloc::string::String,
     /// Pipelines with names that match this prefix should be
     /// returned.  If unspecified, all pipelines in the project, up to
     /// `pageSize`, will be returned.
-    #[prost(string, tag = "2")]
+    #[prost(string, tag="2")]
     pub name_prefix: ::prost::alloc::string::String,
     /// Number of pipelines to return at once. Defaults to 256, and max
     /// is 2048.
-    #[prost(int32, tag = "3")]
+    #[prost(int32, tag="3")]
     pub page_size: i32,
     /// Token to use to indicate where to start getting results.
     /// If unspecified, returns the first page of results.
-    #[prost(string, tag = "4")]
+    #[prost(string, tag="4")]
     pub page_token: ::prost::alloc::string::String,
 }
 /// The response of ListPipelines. Contains at most `pageSize`
@@ -222,10 +213,10 @@ pub struct ListPipelinesRequest {
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct ListPipelinesResponse {
     /// The matched pipelines.
-    #[prost(message, repeated, tag = "1")]
+    #[prost(message, repeated, tag="1")]
     pub pipelines: ::prost::alloc::vec::Vec<Pipeline>,
     /// The token to use to get the next page of results.
-    #[prost(string, tag = "2")]
+    #[prost(string, tag="2")]
     pub next_page_token: ::prost::alloc::string::String,
 }
 /// The request to delete a saved pipeline by ID.
@@ -233,7 +224,7 @@ pub struct ListPipelinesResponse {
 pub struct DeletePipelineRequest {
     /// Caller must have WRITE access to the project in which this pipeline
     /// is defined.
-    #[prost(string, tag = "1")]
+    #[prost(string, tag="1")]
     pub pipeline_id: ::prost::alloc::string::String,
 }
 /// Request to get controller configuation.  Should only be used
@@ -241,9 +232,9 @@ pub struct DeletePipelineRequest {
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct GetControllerConfigRequest {
     /// The operation to retrieve controller configuration for.
-    #[prost(string, tag = "1")]
+    #[prost(string, tag="1")]
     pub operation_id: ::prost::alloc::string::String,
-    #[prost(uint64, tag = "2")]
+    #[prost(uint64, tag="2")]
     pub validation_token: u64,
 }
 /// Stores the information that the controller will fetch from the
@@ -251,40 +242,28 @@ pub struct GetControllerConfigRequest {
 /// Pipelines Service and not by end users.
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct ControllerConfig {
-    #[prost(string, tag = "1")]
+    #[prost(string, tag="1")]
     pub image: ::prost::alloc::string::String,
-    #[prost(string, tag = "2")]
+    #[prost(string, tag="2")]
     pub cmd: ::prost::alloc::string::String,
-    #[prost(string, tag = "3")]
+    #[prost(string, tag="3")]
     pub gcs_log_path: ::prost::alloc::string::String,
-    #[prost(string, tag = "4")]
+    #[prost(string, tag="4")]
     pub machine_type: ::prost::alloc::string::String,
-    #[prost(btree_map = "string, string", tag = "5")]
-    pub vars: ::prost::alloc::collections::BTreeMap<
-        ::prost::alloc::string::String,
-        ::prost::alloc::string::String,
-    >,
-    #[prost(btree_map = "string, string", tag = "6")]
-    pub disks: ::prost::alloc::collections::BTreeMap<
-        ::prost::alloc::string::String,
-        ::prost::alloc::string::String,
-    >,
-    #[prost(btree_map = "string, message", tag = "7")]
-    pub gcs_sources: ::prost::alloc::collections::BTreeMap<
-        ::prost::alloc::string::String,
-        controller_config::RepeatedString,
-    >,
-    #[prost(btree_map = "string, message", tag = "8")]
-    pub gcs_sinks: ::prost::alloc::collections::BTreeMap<
-        ::prost::alloc::string::String,
-        controller_config::RepeatedString,
-    >,
+    #[prost(btree_map="string, string", tag="5")]
+    pub vars: ::prost::alloc::collections::BTreeMap<::prost::alloc::string::String, ::prost::alloc::string::String>,
+    #[prost(btree_map="string, string", tag="6")]
+    pub disks: ::prost::alloc::collections::BTreeMap<::prost::alloc::string::String, ::prost::alloc::string::String>,
+    #[prost(btree_map="string, message", tag="7")]
+    pub gcs_sources: ::prost::alloc::collections::BTreeMap<::prost::alloc::string::String, controller_config::RepeatedString>,
+    #[prost(btree_map="string, message", tag="8")]
+    pub gcs_sinks: ::prost::alloc::collections::BTreeMap<::prost::alloc::string::String, controller_config::RepeatedString>,
 }
 /// Nested message and enum types in `ControllerConfig`.
 pub mod controller_config {
     #[derive(Clone, PartialEq, ::prost::Message)]
     pub struct RepeatedString {
-        #[prost(string, repeated, tag = "1")]
+        #[prost(string, repeated, tag="1")]
         pub values: ::prost::alloc::vec::Vec<::prost::alloc::string::String>,
     }
 }
@@ -293,25 +272,25 @@ pub mod controller_config {
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct TimestampEvent {
     /// String indicating the type of event
-    #[prost(string, tag = "1")]
+    #[prost(string, tag="1")]
     pub description: ::prost::alloc::string::String,
     /// The time this event occured.
-    #[prost(message, optional, tag = "2")]
+    #[prost(message, optional, tag="2")]
     pub timestamp: ::core::option::Option<::prost_types::Timestamp>,
 }
 /// Request to set operation status. Should only be used by VMs
 /// created by the Pipelines Service and not by end users.
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct SetOperationStatusRequest {
-    #[prost(string, tag = "1")]
+    #[prost(string, tag="1")]
     pub operation_id: ::prost::alloc::string::String,
-    #[prost(message, repeated, tag = "2")]
+    #[prost(message, repeated, tag="2")]
     pub timestamp_events: ::prost::alloc::vec::Vec<TimestampEvent>,
-    #[prost(enumeration = "super::super::rpc::Code", tag = "3")]
+    #[prost(enumeration="super::super::rpc::Code", tag="3")]
     pub error_code: i32,
-    #[prost(string, tag = "4")]
+    #[prost(string, tag="4")]
     pub error_message: ::prost::alloc::string::String,
-    #[prost(uint64, tag = "5")]
+    #[prost(uint64, tag="5")]
     pub validation_token: u64,
 }
 /// A Google Cloud Service Account.
@@ -319,7 +298,7 @@ pub struct SetOperationStatusRequest {
 pub struct ServiceAccount {
     /// Email address of the service account. Defaults to `default`,
     /// which uses the compute service account associated with the project.
-    #[prost(string, tag = "1")]
+    #[prost(string, tag="1")]
     pub email: ::prost::alloc::string::String,
     /// List of scopes to be enabled for this service account on the VM.
     /// The following scopes are automatically included:
@@ -329,7 +308,7 @@ pub struct ServiceAccount {
     /// * <https://www.googleapis.com/auth/genomics>
     /// * <https://www.googleapis.com/auth/logging.write>
     /// * <https://www.googleapis.com/auth/monitoring.write>
-    #[prost(string, repeated, tag = "2")]
+    #[prost(string, repeated, tag="2")]
     pub scopes: ::prost::alloc::vec::Vec<::prost::alloc::string::String>,
 }
 /// The logging options for the pipeline run.
@@ -343,32 +322,32 @@ pub struct LoggingOptions {
     /// used, and the user must ensure that logs are not
     /// overwritten. Stdout and stderr logs from the run are also
     /// generated and output as `-stdout.log` and `-stderr.log`.
-    #[prost(string, tag = "1")]
+    #[prost(string, tag="1")]
     pub gcs_path: ::prost::alloc::string::String,
 }
 /// The system resources for the pipeline run.
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct PipelineResources {
     /// The minimum number of cores to use. Defaults to 1.
-    #[prost(int32, tag = "1")]
+    #[prost(int32, tag="1")]
     pub minimum_cpu_cores: i32,
     /// Whether to use preemptible VMs. Defaults to `false`. In order to use this,
     /// must be true for both create time and run time. Cannot be true at run time
     /// if false at create time.
-    #[prost(bool, tag = "2")]
+    #[prost(bool, tag="2")]
     pub preemptible: bool,
     /// The minimum amount of RAM to use. Defaults to 3.75 (GB)
-    #[prost(double, tag = "3")]
+    #[prost(double, tag="3")]
     pub minimum_ram_gb: f64,
     /// Disks to attach.
-    #[prost(message, repeated, tag = "4")]
+    #[prost(message, repeated, tag="4")]
     pub disks: ::prost::alloc::vec::Vec<pipeline_resources::Disk>,
     /// List of Google Compute Engine availability zones to which resource
     /// creation will restricted. If empty, any zone may be chosen.
-    #[prost(string, repeated, tag = "5")]
+    #[prost(string, repeated, tag="5")]
     pub zones: ::prost::alloc::vec::Vec<::prost::alloc::string::String>,
     /// The size of the boot disk. Defaults to 10 (GB).
-    #[prost(int32, tag = "6")]
+    #[prost(int32, tag="6")]
     pub boot_disk_size_gb: i32,
     /// Whether to assign an external IP to the instance. This is an experimental
     /// feature that may go away. Defaults to false.
@@ -381,7 +360,7 @@ pub struct PipelineResources {
     /// only load docker images from Google Container Registry and not Docker Hub.
     /// ** Note: To use this option, your project must be in Google Access for
     /// Private IPs Early Access Program.**
-    #[prost(bool, tag = "7")]
+    #[prost(bool, tag="7")]
     pub no_address: bool,
 }
 /// Nested message and enum types in `PipelineResources`.
@@ -392,25 +371,25 @@ pub mod pipeline_resources {
         /// Required. The name of the disk that can be used in the pipeline
         /// parameters. Must be 1 - 63 characters.
         /// The name "boot" is reserved for system use.
-        #[prost(string, tag = "1")]
+        #[prost(string, tag="1")]
         pub name: ::prost::alloc::string::String,
         /// Required. The type of the disk to create.
-        #[prost(enumeration = "disk::Type", tag = "2")]
+        #[prost(enumeration="disk::Type", tag="2")]
         pub r#type: i32,
         /// The size of the disk. Defaults to 500 (GB).
         /// This field is not applicable for local SSD.
-        #[prost(int32, tag = "3")]
+        #[prost(int32, tag="3")]
         pub size_gb: i32,
         /// The full or partial URL of the persistent disk to attach. See
         /// <https://cloud.google.com/compute/docs/reference/latest/instances#resource>
         /// and
         /// <https://cloud.google.com/compute/docs/disks/persistent-disks#snapshots>
         /// for more details.
-        #[prost(string, tag = "4")]
+        #[prost(string, tag="4")]
         pub source: ::prost::alloc::string::String,
         /// Deprecated. Disks created by the Pipelines API will be deleted at the end
         /// of the pipeline run, regardless of what this field is set to.
-        #[prost(bool, tag = "6")]
+        #[prost(bool, tag="6")]
         pub auto_delete: bool,
         /// Required at create time and cannot be overridden at run time.
         /// Specifies the path in the docker container where files on
@@ -418,15 +397,13 @@ pub mod pipeline_resources {
         /// is `/mnt/disk`, and the parameter has `localPath`
         /// `inputs/file.txt`, the docker container can access the data at
         /// `/mnt/disk/inputs/file.txt`.
-        #[prost(string, tag = "8")]
+        #[prost(string, tag="8")]
         pub mount_point: ::prost::alloc::string::String,
     }
     /// Nested message and enum types in `Disk`.
     pub mod disk {
         /// The types of disks that may be attached to VMs.
-        #[derive(
-            Clone, Copy, Debug, PartialEq, Eq, Hash, PartialOrd, Ord, ::prost::Enumeration,
-        )]
+        #[derive(Clone, Copy, Debug, PartialEq, Eq, Hash, PartialOrd, Ord, ::prost::Enumeration)]
         #[repr(i32)]
         pub enum Type {
             /// Default disk type. Use one of the other options below.
@@ -538,21 +515,21 @@ pub mod pipeline_resources {
 pub struct PipelineParameter {
     /// Required. Name of the parameter - the pipeline runner uses this string
     /// as the key to the input and output maps in RunPipeline.
-    #[prost(string, tag = "1")]
+    #[prost(string, tag="1")]
     pub name: ::prost::alloc::string::String,
     /// Human-readable description.
-    #[prost(string, tag = "2")]
+    #[prost(string, tag="2")]
     pub description: ::prost::alloc::string::String,
     /// The default value for this parameter. Can be overridden at runtime.
     /// If `localCopy` is present, then this must be a Google Cloud Storage path
     /// beginning with `gs://`.
-    #[prost(string, tag = "5")]
+    #[prost(string, tag="5")]
     pub default_value: ::prost::alloc::string::String,
     /// If present, this parameter is marked for copying to and from the VM.
     /// `LocalCopy` indicates where on the VM the file should be. The value
     /// given to this parameter (either at runtime or using `defaultValue`)
     /// must be the remote path where the file should be.
-    #[prost(message, optional, tag = "6")]
+    #[prost(message, optional, tag="6")]
     pub local_copy: ::core::option::Option<pipeline_parameter::LocalCopy>,
 }
 /// Nested message and enum types in `PipelineParameter`.
@@ -563,13 +540,13 @@ pub mod pipeline_parameter {
         /// Required. The path within the user's docker container where
         /// this input should be localized to and from, relative to the specified
         /// disk's mount point. For example: file.txt,
-        #[prost(string, tag = "1")]
+        #[prost(string, tag="1")]
         pub path: ::prost::alloc::string::String,
         /// Required. The name of the disk where this parameter is
         /// located. Can be the name of one of the disks specified in the
         /// Resources field, or "boot", which represents the Docker
         /// instance's boot disk and has a mount point of `/`.
-        #[prost(string, tag = "2")]
+        #[prost(string, tag="2")]
         pub disk: ::prost::alloc::string::String,
     }
 }
@@ -578,7 +555,7 @@ pub mod pipeline_parameter {
 pub struct DockerExecutor {
     /// Required. Image name from either Docker Hub or Google Container Registry.
     /// Users that run pipelines must have READ access to the image.
-    #[prost(string, tag = "1")]
+    #[prost(string, tag="1")]
     pub image_name: ::prost::alloc::string::String,
     /// Required. The command or newline delimited script to run. The command
     /// string will be executed within a bash shell.
@@ -588,14 +565,14 @@ pub struct DockerExecutor {
     /// \[`error`][google.longrunning.Operation.error\] field will be populated.
     ///
     /// Maximum command string length is 16384.
-    #[prost(string, tag = "2")]
+    #[prost(string, tag="2")]
     pub cmd: ::prost::alloc::string::String,
 }
-#[doc = r" Generated client implementations."]
+/// Generated client implementations.
 pub mod pipelines_v1_alpha2_client {
     #![allow(unused_variables, dead_code, missing_docs, clippy::let_unit_value)]
     use tonic::codegen::*;
-    #[doc = " A service for running genomics pipelines."]
+    /// A service for running genomics pipelines.
     #[derive(Debug, Clone)]
     pub struct PipelinesV1Alpha2Client<T> {
         inner: tonic::client::Grpc<T>,
@@ -603,8 +580,8 @@ pub mod pipelines_v1_alpha2_client {
     impl<T> PipelinesV1Alpha2Client<T>
     where
         T: tonic::client::GrpcService<tonic::body::BoxBody>,
-        T::ResponseBody: Body + Send + 'static,
         T::Error: Into<StdError>,
+        T::ResponseBody: Default + Body<Data = Bytes> + Send + 'static,
         <T::ResponseBody as Body>::Error: Into<StdError> + Send,
     {
         pub fn new(inner: T) -> Self {
@@ -623,158 +600,184 @@ pub mod pipelines_v1_alpha2_client {
                     <T as tonic::client::GrpcService<tonic::body::BoxBody>>::ResponseBody,
                 >,
             >,
-            <T as tonic::codegen::Service<http::Request<tonic::body::BoxBody>>>::Error:
-                Into<StdError> + Send + Sync,
+            <T as tonic::codegen::Service<
+                http::Request<tonic::body::BoxBody>,
+            >>::Error: Into<StdError> + Send + Sync,
         {
             PipelinesV1Alpha2Client::new(InterceptedService::new(inner, interceptor))
         }
-        #[doc = r" Compress requests with `gzip`."]
-        #[doc = r""]
-        #[doc = r" This requires the server to support it otherwise it might respond with an"]
-        #[doc = r" error."]
+        /// Compress requests with `gzip`.
+        ///
+        /// This requires the server to support it otherwise it might respond with an
+        /// error.
+        #[must_use]
         pub fn send_gzip(mut self) -> Self {
             self.inner = self.inner.send_gzip();
             self
         }
-        #[doc = r" Enable decompressing responses with `gzip`."]
+        /// Enable decompressing responses with `gzip`.
+        #[must_use]
         pub fn accept_gzip(mut self) -> Self {
             self.inner = self.inner.accept_gzip();
             self
         }
-        #[doc = " Creates a pipeline that can be run later. Create takes a Pipeline that"]
-        #[doc = " has all fields other than `pipelineId` populated, and then returns"]
-        #[doc = " the same pipeline with `pipelineId` populated. This id can be used"]
-        #[doc = " to run the pipeline."]
-        #[doc = ""]
-        #[doc = " Caller must have WRITE permission to the project."]
+        /// Creates a pipeline that can be run later. Create takes a Pipeline that
+        /// has all fields other than `pipelineId` populated, and then returns
+        /// the same pipeline with `pipelineId` populated. This id can be used
+        /// to run the pipeline.
+        ///
+        /// Caller must have WRITE permission to the project.
         pub async fn create_pipeline(
             &mut self,
             request: impl tonic::IntoRequest<super::CreatePipelineRequest>,
         ) -> Result<tonic::Response<super::Pipeline>, tonic::Status> {
-            self.inner.ready().await.map_err(|e| {
-                tonic::Status::new(
-                    tonic::Code::Unknown,
-                    format!("Service was not ready: {}", e.into()),
-                )
-            })?;
+            self.inner
+                .ready()
+                .await
+                .map_err(|e| {
+                    tonic::Status::new(
+                        tonic::Code::Unknown,
+                        format!("Service was not ready: {}", e.into()),
+                    )
+                })?;
             let codec = tonic::codec::ProstCodec::default();
             let path = http::uri::PathAndQuery::from_static(
                 "/google.genomics.v1alpha2.PipelinesV1Alpha2/CreatePipeline",
             );
             self.inner.unary(request.into_request(), path, codec).await
         }
-        #[doc = " Runs a pipeline. If `pipelineId` is specified in the request, then"]
-        #[doc = " run a saved pipeline. If `ephemeralPipeline` is specified, then run"]
-        #[doc = " that pipeline once without saving a copy."]
-        #[doc = ""]
-        #[doc = " The caller must have READ permission to the project where the pipeline"]
-        #[doc = " is stored and WRITE permission to the project where the pipeline will be"]
-        #[doc = " run, as VMs will be created and storage will be used."]
+        /// Runs a pipeline. If `pipelineId` is specified in the request, then
+        /// run a saved pipeline. If `ephemeralPipeline` is specified, then run
+        /// that pipeline once without saving a copy.
+        ///
+        /// The caller must have READ permission to the project where the pipeline
+        /// is stored and WRITE permission to the project where the pipeline will be
+        /// run, as VMs will be created and storage will be used.
         pub async fn run_pipeline(
             &mut self,
             request: impl tonic::IntoRequest<super::RunPipelineRequest>,
-        ) -> Result<tonic::Response<super::super::super::longrunning::Operation>, tonic::Status>
-        {
-            self.inner.ready().await.map_err(|e| {
-                tonic::Status::new(
-                    tonic::Code::Unknown,
-                    format!("Service was not ready: {}", e.into()),
-                )
-            })?;
+        ) -> Result<
+                tonic::Response<super::super::super::longrunning::Operation>,
+                tonic::Status,
+            > {
+            self.inner
+                .ready()
+                .await
+                .map_err(|e| {
+                    tonic::Status::new(
+                        tonic::Code::Unknown,
+                        format!("Service was not ready: {}", e.into()),
+                    )
+                })?;
             let codec = tonic::codec::ProstCodec::default();
             let path = http::uri::PathAndQuery::from_static(
                 "/google.genomics.v1alpha2.PipelinesV1Alpha2/RunPipeline",
             );
             self.inner.unary(request.into_request(), path, codec).await
         }
-        #[doc = " Retrieves a pipeline based on ID."]
-        #[doc = ""]
-        #[doc = " Caller must have READ permission to the project."]
+        /// Retrieves a pipeline based on ID.
+        ///
+        /// Caller must have READ permission to the project.
         pub async fn get_pipeline(
             &mut self,
             request: impl tonic::IntoRequest<super::GetPipelineRequest>,
         ) -> Result<tonic::Response<super::Pipeline>, tonic::Status> {
-            self.inner.ready().await.map_err(|e| {
-                tonic::Status::new(
-                    tonic::Code::Unknown,
-                    format!("Service was not ready: {}", e.into()),
-                )
-            })?;
+            self.inner
+                .ready()
+                .await
+                .map_err(|e| {
+                    tonic::Status::new(
+                        tonic::Code::Unknown,
+                        format!("Service was not ready: {}", e.into()),
+                    )
+                })?;
             let codec = tonic::codec::ProstCodec::default();
             let path = http::uri::PathAndQuery::from_static(
                 "/google.genomics.v1alpha2.PipelinesV1Alpha2/GetPipeline",
             );
             self.inner.unary(request.into_request(), path, codec).await
         }
-        #[doc = " Lists pipelines."]
-        #[doc = ""]
-        #[doc = " Caller must have READ permission to the project."]
+        /// Lists pipelines.
+        ///
+        /// Caller must have READ permission to the project.
         pub async fn list_pipelines(
             &mut self,
             request: impl tonic::IntoRequest<super::ListPipelinesRequest>,
         ) -> Result<tonic::Response<super::ListPipelinesResponse>, tonic::Status> {
-            self.inner.ready().await.map_err(|e| {
-                tonic::Status::new(
-                    tonic::Code::Unknown,
-                    format!("Service was not ready: {}", e.into()),
-                )
-            })?;
+            self.inner
+                .ready()
+                .await
+                .map_err(|e| {
+                    tonic::Status::new(
+                        tonic::Code::Unknown,
+                        format!("Service was not ready: {}", e.into()),
+                    )
+                })?;
             let codec = tonic::codec::ProstCodec::default();
             let path = http::uri::PathAndQuery::from_static(
                 "/google.genomics.v1alpha2.PipelinesV1Alpha2/ListPipelines",
             );
             self.inner.unary(request.into_request(), path, codec).await
         }
-        #[doc = " Deletes a pipeline based on ID."]
-        #[doc = ""]
-        #[doc = " Caller must have WRITE permission to the project."]
+        /// Deletes a pipeline based on ID.
+        ///
+        /// Caller must have WRITE permission to the project.
         pub async fn delete_pipeline(
             &mut self,
             request: impl tonic::IntoRequest<super::DeletePipelineRequest>,
         ) -> Result<tonic::Response<()>, tonic::Status> {
-            self.inner.ready().await.map_err(|e| {
-                tonic::Status::new(
-                    tonic::Code::Unknown,
-                    format!("Service was not ready: {}", e.into()),
-                )
-            })?;
+            self.inner
+                .ready()
+                .await
+                .map_err(|e| {
+                    tonic::Status::new(
+                        tonic::Code::Unknown,
+                        format!("Service was not ready: {}", e.into()),
+                    )
+                })?;
             let codec = tonic::codec::ProstCodec::default();
             let path = http::uri::PathAndQuery::from_static(
                 "/google.genomics.v1alpha2.PipelinesV1Alpha2/DeletePipeline",
             );
             self.inner.unary(request.into_request(), path, codec).await
         }
-        #[doc = " Gets controller configuration information. Should only be called"]
-        #[doc = " by VMs created by the Pipelines Service and not by end users."]
+        /// Gets controller configuration information. Should only be called
+        /// by VMs created by the Pipelines Service and not by end users.
         pub async fn get_controller_config(
             &mut self,
             request: impl tonic::IntoRequest<super::GetControllerConfigRequest>,
         ) -> Result<tonic::Response<super::ControllerConfig>, tonic::Status> {
-            self.inner.ready().await.map_err(|e| {
-                tonic::Status::new(
-                    tonic::Code::Unknown,
-                    format!("Service was not ready: {}", e.into()),
-                )
-            })?;
+            self.inner
+                .ready()
+                .await
+                .map_err(|e| {
+                    tonic::Status::new(
+                        tonic::Code::Unknown,
+                        format!("Service was not ready: {}", e.into()),
+                    )
+                })?;
             let codec = tonic::codec::ProstCodec::default();
             let path = http::uri::PathAndQuery::from_static(
                 "/google.genomics.v1alpha2.PipelinesV1Alpha2/GetControllerConfig",
             );
             self.inner.unary(request.into_request(), path, codec).await
         }
-        #[doc = " Sets status of a given operation. Any new timestamps (as determined by"]
-        #[doc = " description) are appended to TimestampEvents. Should only be called by VMs"]
-        #[doc = " created by the Pipelines Service and not by end users."]
+        /// Sets status of a given operation. Any new timestamps (as determined by
+        /// description) are appended to TimestampEvents. Should only be called by VMs
+        /// created by the Pipelines Service and not by end users.
         pub async fn set_operation_status(
             &mut self,
             request: impl tonic::IntoRequest<super::SetOperationStatusRequest>,
         ) -> Result<tonic::Response<()>, tonic::Status> {
-            self.inner.ready().await.map_err(|e| {
-                tonic::Status::new(
-                    tonic::Code::Unknown,
-                    format!("Service was not ready: {}", e.into()),
-                )
-            })?;
+            self.inner
+                .ready()
+                .await
+                .map_err(|e| {
+                    tonic::Status::new(
+                        tonic::Code::Unknown,
+                        format!("Service was not ready: {}", e.into()),
+                    )
+                })?;
             let codec = tonic::codec::ProstCodec::default();
             let path = http::uri::PathAndQuery::from_static(
                 "/google.genomics.v1alpha2.PipelinesV1Alpha2/SetOperationStatus",
